# Change Log

## 0.4.0
* Drop py27 support and add badges [#15](https://github.com/jupyterlab/pytest-check-links/pull/15)
* Use requests(-cache) [#12](https://github.com/jupyterlab/pytest-check-links/pull/12)
* Add checking of self- and local html anchors  [#10](https://github.com/jupyterlab/pytest-check-links/pull/10)

## 0.3.0
* Honor Retry-After Header [#9](https://github.com/jupyterlab/pytest-check-links/pull/9)
* Update metadata for JupyterLab Org [#7](https://github.com/jupyterlab/pytest-check-links/pull/7)

## 0.2.0
* Add rst handling [#4](https://github.com/jupyterlab/pytest-check-links/pull/4)
